import { ElementNode } from '@lightningjs/solid';
export interface DefaultKeyMap {
    Left: string;
    Right: string;
    Up: string;
    Down: string;
    Enter: string;
    Last: string;
}
export interface KeyMap extends DefaultKeyMap {
}
export type KeyHandlerReturn = boolean | void;
export type KeyHandler = (this: ElementNode, e: KeyboardEvent, target: ElementNode) => KeyHandlerReturn;
/**
 * Generates a map of event handlers for each key in the KeyMap
 */
type KeyMapEventHandlers = {
    [K in keyof KeyMap as `on${Capitalize<K>}`]?: KeyHandler;
};
declare module '@lightningjs/solid' {
    /**
     * Augment the existing IntrinsicCommonProps interface with our own
     * FocusManager-specific properties.
     */
    interface IntrinsicCommonProps extends KeyMapEventHandlers {
        onFocus?: (currentFocusedElm: ElementNode | null, prevFocusedElm: ElementNode | null) => void;
        onBlur?: (currentFocusedElm: ElementNode | null, prevFocusedElm: ElementNode | null) => void;
        onKeyPress?: (this: ElementNode, e: KeyboardEvent, mappedKeyEvent: string | undefined, currentFocusedElm: ElementNode) => KeyHandlerReturn;
        onSelectedChanged?: (container: ElementNode, activeElm: ElementNode, selectedIndex: number | null, lastSelectedIndex: number | null) => void;
        skipFocus?: boolean;
        wrap?: boolean;
        plinko?: boolean;
    }
    interface IntrinsicNodeStyleProps {
        focus?: IntrinsicNodeStyleProps;
    }
    interface IntrinsicTextNodeStyleProps {
        focus?: IntrinsicTextNodeStyleProps;
    }
    interface TextNode {
        skipFocus?: undefined;
    }
}
declare const focusPath: import("solid-js").Accessor<ElementNode[]>;
export { focusPath };
export declare const useFocusManager: (userKeyMap?: Partial<KeyMap>) => import("solid-js").Accessor<ElementNode[]>;
