/*
 * Copyright 2023 Comcast Cable Communications Management, LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */
import { ElementNode } from '@lightningjs/solid';
// To use with TS import withAlign and then put withAlign; on the next line to prevent tree shaking
export function withAlign(el, alignment) {
    const align = alignment();
    if (align) {
        el.onLayout = (node) => {
            let maxHeight = node.parent.height || 0;
            if (align === 'bottom') {
                node.children.forEach((c) => {
                    c.mountY = 1;
                    c.y = (c.height || 0) * -1;
                });
            }
            else if (align === 'center') {
                if (!maxHeight) {
                    node.children.forEach((c) => {
                        if (c.height && c.height > maxHeight) {
                            maxHeight = c.height;
                        }
                    });
                }
                node.children.forEach((c) => {
                    c.y = (maxHeight - (c.height || 0)) / 2;
                });
            }
        };
    }
}
//# sourceMappingURL=withAlign.js.map